package sql

import (
	"context"
	"github.com/uptrace/bun"
	"time"
)

type Download struct {
	bun.BaseModel `bun:"table:downloads,alias:d"`
	ID            string    `bun:"id,pk,type:uuid,default:uuid_generate_v4()"`
	Status        string    `bun:"status,notnull"`
	Link          string    `bun:"link,notnull"`
	CreatedAt     time.Time `bun:"created_at,nullzero,notnull,default:current_timestamp"`
	UpdatedAt     time.Time `bun:"updated_at,nullzero,notnull,default:current_timestamp"`
}

var _ bun.BeforeAppendModelHook = (*Download)(nil)

func (u *Download) BeforeAppendModel(ctx context.Context, query bun.Query) error {
	switch query.(type) {
	case *bun.InsertQuery:
		u.CreatedAt = time.Now()
		u.UpdatedAt = time.Now()
	case *bun.UpdateQuery:
		u.UpdatedAt = time.Now()
	}
	return nil
}
