package local

import (
	"downloader/internal/core/ports/filehandler/mover"
	"downloader/pkg/files"
	"fmt"
	"go.uber.org/zap"
	"os"
)

type Mover struct {
	logger *zap.SugaredLogger
}

func New(logger *zap.SugaredLogger) mover.Mover {
	return &Mover{logger: logger}
}

func (m *Mover) Move(sourceDirectory string, destinationDirectory string) error {
	dir, err := os.ReadDir(sourceDirectory)
	if err != nil {
		m.logger.Error("Could not read directory")
		return err
	}

	for _, fileInfo := range dir {
		oldPath := fmt.Sprintf("%s/%s", sourceDirectory, fileInfo.Name())
		newPath := fmt.Sprintf("%s/%s", destinationDirectory, fileInfo.Name())

		if err := files.MoveFile(oldPath, newPath); err != nil {
			return err
		} else {
			m.logger.Infow("moved file",
				"fileName", fileInfo.Name())
		}
	}

	return nil
}
