package destinationhandler

import (
	"downloader/internal/core/ports/filehandler/mover"
	"github.com/ovh/configstore"
	"os"
)

type DestinationHandler interface {
	Prepare() error
	Move(sourcePath string) error
}

type localDestinationHandler struct {
	outputDirectory string
	mover           mover.Mover
}

func New(mover mover.Mover) DestinationHandler {
	outputDirectory, err := configstore.GetItemValue("download_output")
	if err != nil {
		panic(err)
	}
	return &localDestinationHandler{
		outputDirectory: outputDirectory,
		mover:           mover,
	}
}

func (l localDestinationHandler) Prepare() error {
	return os.MkdirAll(l.outputDirectory, os.ModePerm)
}

func (l localDestinationHandler) Move(sourcePath string) error {
	return l.mover.Move(sourcePath, l.outputDirectory)
}
