package fileorchestrator

import (
	"downloader/internal/core/ports/fileorchestrator/destinationhandler"
	"downloader/internal/core/ports/fileorchestrator/sourcehandler"
	"go.uber.org/zap"
)

type FileOrchestrator struct {
	logger             *zap.SugaredLogger
	sourceHandler      sourcehandler.SourceHandler
	destinationHandler destinationhandler.DestinationHandler
}

func New(logger *zap.SugaredLogger, sourceHandler sourcehandler.SourceHandler, destinationHandler destinationhandler.DestinationHandler) *FileOrchestrator {
	return &FileOrchestrator{
		logger:             logger,
		sourceHandler:      sourceHandler,
		destinationHandler: destinationHandler,
	}
}

func (o *FileOrchestrator) Begin(link string) (string, error) {
	basePath, err := o.sourceHandler.Prepare(link)
	err = o.destinationHandler.Prepare()

	return basePath, err
}

func (o *FileOrchestrator) CleanUp(sourceDirectory string) {
	err := o.sourceHandler.CleanUp(sourceDirectory)
	if err != nil {
		o.logger.Errorw("could not cleanup",
			"path", sourceDirectory)
	}
}

func (o *FileOrchestrator) Move(sourcePath string) error {
	return o.destinationHandler.Move(sourcePath)
}
