package sourcehandler

import (
	"crypto/sha256"
	"fmt"
	"github.com/ovh/configstore"
	"os"
)

type SourceHandler interface {
	Prepare(link string) (string, error)
	CleanUp(sourcePath string) error
}

type localSourceHandler struct {
	outputTmpDirectory string
}

func New() SourceHandler {
	outputTmpDirectory, err := configstore.GetItemValue("download_tmp_output")
	if err != nil {
		panic(err)
	}
	return &localSourceHandler{
		outputTmpDirectory: outputTmpDirectory,
	}
}

func (l localSourceHandler) Prepare(link string) (string, error) {
	path := fmt.Sprintf("%s/%x",
		l.outputTmpDirectory,
		sha256.Sum256([]byte(link)))
	err := os.MkdirAll(path, os.ModePerm)
	return path, err
}

func (l localSourceHandler) CleanUp(sourcePath string) error {
	if _, err := os.Stat(sourcePath); os.IsNotExist(err) {
		return nil
	}
	return os.RemoveAll(sourcePath)
}
