package _default

import (
	"context"
	"downloader/internal/core/entities"
	"downloader/internal/core/ports/download_request"
	"downloader/internal/core/services/download"
	"downloader/internal/core/services/downloader"
	"go.uber.org/zap"
)

type localBackgroundService struct {
	repository download_request.Repository
	logger     *zap.SugaredLogger
	downloader downloader.Downloader
}

func NewLocalBackgroundService(repository download_request.Repository, logger *zap.SugaredLogger, downloader downloader.Downloader) download.BackgroundService {
	return &localBackgroundService{repository: repository, logger: logger, downloader: downloader}
}

func (l localBackgroundService) Run(ctx context.Context, download *entities.Download) error {
	logger := l.logger.With("downloadId", download.ID)

	go func() {
		longRunningCtx := context.TODO()
		download.Status = "started"
		_ = l.repository.Update(longRunningCtx, download)

		err := l.downloader.Download(download.Link, download.ID)
		download.Status = "done"

		if err != nil {
			logger.Error(err)
			download.Status = "failed"
		}

		err = l.repository.Update(longRunningCtx, download)
		if err != nil {
			logger.Errorw("download request failed",
				"downloadLink", download.Link)
			download.Status = "failed"

			if updateErr := l.repository.Update(longRunningCtx, download); updateErr != nil {
				panic(updateErr)
			}
		} else {
			logger.Info("download request done")
		}
	}()

	return nil
}
