package _default

import (
	"context"
	"downloader/internal/core/entities"
	"downloader/internal/core/ports/download_request"
	"downloader/internal/core/services/download"
	"downloader/pkg/common/uuid"
	"go.uber.org/zap"
)

type localService struct {
	repository        download_request.Repository
	uuidGen           uuid.Gen
	BackgroundService download.BackgroundService
	logger            *zap.SugaredLogger
}

func NewLocalService(repository download_request.Repository, uuidGen uuid.Gen, backgroundService download.BackgroundService, logger *zap.SugaredLogger) download.Service {
	return &localService{
		repository:        repository,
		uuidGen:           uuidGen,
		BackgroundService: backgroundService,
		logger:            logger,
	}
}

func (l *localService) Schedule(ctx context.Context, link string) (*entities.Download, error) {
	download, err := entities.NewDownload(link)(l.uuidGen)
	if err != nil {
		l.logger.Warn("Could not parse download")
		return nil, err
	}

	logger := l.logger.With("downloadId", download.ID)

	persistedDownloadRequest, uploadErr := l.repository.Create(ctx, download)
	if uploadErr != nil {
		logger.Error("failed to insert download request")
		return nil, uploadErr
	}

	err = l.BackgroundService.Run(ctx, persistedDownloadRequest)
	if err != nil {
		logger.Error("failed to run download request")
		return nil, err
	}

	return persistedDownloadRequest, nil
}

func (l *localService) Get(ctx context.Context, id string) (*entities.Download, error) {
	return l.repository.GetById(ctx, id)
}

func (l *localService) GetAll(ctx context.Context, active bool) ([]*entities.Download, error) {
	return l.repository.Get(ctx, active)
}

func (l *localService) GetDone(ctx context.Context) ([]*entities.Download, error) {
	return l.repository.GetDone(ctx)
}
